<?php
/**
 * Admin Class
 */
class RPG_Admin {
    /**
     * Constructor
     */
    public function __construct() {
        add_action('admin_menu', array($this, 'add_menu_page'));
        add_action('admin_init', array($this, 'register_settings'));
        add_action('admin_enqueue_scripts', array($this, 'enqueue_admin_scripts'));
    }

    /**
     * Add menu page
     */
    public function add_menu_page() {
        add_menu_page(
            __('Random Grid Display Settings', 'random-post-grid'),
            __('Grid Display', 'random-post-grid'),
            'manage_options',
            'grid-display-settings',
            array($this, 'render_settings_page'),
            'dashicons-screenoptions',
            25
        );
    }

    /**
     * Register settings
     */
    public function register_settings() {
        register_setting('grid_display_options_group', 'grid_post_order');
        register_setting('grid_display_options_group', 'grid_excluded_categories');
        register_setting('grid_display_options_group', 'grid_category_bg_color');
        register_setting('grid_display_options_group', 'grid_category_font_color');
        register_setting('grid_display_options_group', 'grid_title_bg_color');
        register_setting('grid_display_options_group', 'grid_title_font_color');

        add_settings_section(
            'grid_display_main_section',
            __('Grid Display Settings', 'random-post-grid'),
            null,
            'grid-display-settings'
        );

        $this->add_settings_fields();
    }

    /**
     * Add settings fields
     */
    private function add_settings_fields() {
        $fields = array(
            'grid_post_order' => array(
                'title' => __('Post Order', 'random-post-grid'),
                'callback' => 'render_post_order_field'
            ),
            'grid_excluded_categories' => array(
                'title' => __('Exclude Categories', 'random-post-grid'),
                'callback' => 'render_excluded_categories_field'
            ),
            'grid_category_bg_color' => array(
                'title' => __('Category Background Color', 'random-post-grid'),
                'callback' => 'render_color_field'
            ),
            'grid_category_font_color' => array(
                'title' => __('Category Font Color', 'random-post-grid'),
                'callback' => 'render_color_field'
            ),
            'grid_title_bg_color' => array(
                'title' => __('Title Background Color', 'random-post-grid'),
                'callback' => 'render_color_field'
            ),
            'grid_title_font_color' => array(
                'title' => __('Title Font Color', 'random-post-grid'),
                'callback' => 'render_color_field'
            )
        );

        foreach ($fields as $id => $field) {
            add_settings_field(
                $id,
                $field['title'],
                array($this, $field['callback']),
                'grid-display-settings',
                'grid_display_main_section',
                array('id' => $id)
            );
        }
    }

    /**
     * Enqueue admin scripts
     */
    public function enqueue_admin_scripts($hook) {
        if ('toplevel_page_grid-display-settings' !== $hook) {
            return;
        }

        wp_enqueue_style(
            'wp-color-picker'
        );

        wp_enqueue_script(
            'wp-color-picker'
        );

        wp_add_inline_script('wp-color-picker', '
            jQuery(document).ready(function($) {
                $(".color-picker").wpColorPicker();
            });
        ');
    }

    /**
     * Render settings page
     */
    public function render_settings_page() {
        if (!current_user_can('manage_options')) {
            return;
        }
        ?>
        <div class="wrap">
            <h1><?php echo esc_html(get_admin_page_title()); ?></h1>
            <form method="post" action="options.php">
                <?php
                settings_fields('grid_display_options_group');
                do_settings_sections('grid-display-settings');
                submit_button();
                ?>
            </form>
        </div>
        <?php
    }

    /**
     * Render post order field
     */
    public function render_post_order_field($args) {
        $value = get_option($args['id'], 'rand');
        $options = array(
            'date' => __('Newest to Oldest', 'random-post-grid'),
            'title' => __('Title (A-Z)', 'random-post-grid'),
            'rand' => __('Random', 'random-post-grid'),
            'comment_count' => __('Most Commented', 'random-post-grid'),
            'meta_value_num' => __('Custom Meta Value (Number)', 'random-post-grid'),
        );

        echo '<select name="' . esc_attr($args['id']) . '">';
        foreach ($options as $key => $label) {
            printf(
                '<option value="%s" %s>%s</option>',
                esc_attr($key),
                selected($value, $key, false),
                esc_html($label)
            );
        }
        echo '</select>';
    }

    /**
     * Render excluded categories field
     */
    public function render_excluded_categories_field($args) {
        $value = get_option($args['id'], '');
        printf(
            '<input type="text" name="%s" value="%s" placeholder="%s" />',
            esc_attr($args['id']),
            esc_attr($value),
            esc_attr__('Enter category IDs separated by commas (e.g., 1,3,7)', 'random-post-grid')
        );
    }

    /**
     * Render color field
     */
    public function render_color_field($args) {
        $value = get_option($args['id'], '#000000');
        printf(
            '<input type="text" class="color-picker" name="%s" value="%s" />',
            esc_attr($args['id']),
            esc_attr($value)
        );
    }
} 