<?php
/**
 * Grid Display Class
 */
class RPG_Grid_Display {
    /**
     * Constructor
     */
    public function __construct() {
        add_shortcode('random_post_grid', array($this, 'render_grid'));
        add_action('wp_enqueue_scripts', array($this, 'enqueue_styles'));
    }

    /**
     * Enqueue styles
     */
    public function enqueue_styles() {
        wp_enqueue_style(
            'rpg-grid-styles',
            RPG_PLUGIN_URL . 'assets/css/grid-styles.css',
            array(),
            RPG_VERSION
        );
    }

    /**
     * Render the grid
     */
    public function render_grid() {
        // Get settings
        $post_order = get_option('grid_post_order', 'rand');
        $excluded_categories = get_option('grid_excluded_categories', '');
        $excluded_categories = array_filter(array_map('intval', explode(',', $excluded_categories)));

        // Build query args
        $args = array(
            'post_type'      => 'post',
            'posts_per_page' => 3,
            'orderby'        => $post_order,
            'no_found_rows'  => true, // Performance improvement for random posts
            'update_post_meta_cache' => false,
            'update_post_term_cache' => false,
            'update_post_meta_cache' => false,
            'cache_results' => false
        );

        if (!empty($excluded_categories)) {
            $args['category__not_in'] = $excluded_categories;
        }

        $query = new WP_Query($args);

        if (!$query->have_posts()) {
            return '<p>' . esc_html__('No posts found.', 'random-post-grid') . '</p>';
        }

        // Get color settings
        $colors = array(
            'category_bg' => esc_attr(get_option('grid_category_bg_color', '#000000')),
            'category_font' => esc_attr(get_option('grid_category_font_color', '#FFFFFF')),
            'title_bg' => esc_attr(get_option('grid_title_bg_color', '#003375')),
            'title_font' => esc_attr(get_option('grid_title_font_color', '#FFFFFF'))
        );

        ob_start();
        ?>
        <div class="custom-grid">
            <?php
            // Featured Post
            $query->the_post();
            $this->render_featured_post($colors);

            // Sidebar Posts
            echo '<div class="sidebar-posts">';
            while ($query->have_posts()) {
                $query->the_post();
                $this->render_sidebar_post($colors);
            }
            echo '</div>';
            ?>
        </div>
        <?php
        wp_reset_postdata();
        return ob_get_clean();
    }

    /**
     * Render featured post
     */
    private function render_featured_post($colors) {
        $image = has_post_thumbnail() ? get_the_post_thumbnail_url(get_the_ID(), 'large') : 'https://via.placeholder.com/800x400';
        $categories = get_the_category();
        ?>
        <a href="<?php echo esc_url(get_permalink()); ?>" class="featured-post" style="background-image: url(<?php echo esc_url($image); ?>);">
            <?php $this->render_categories($categories, $colors); ?>
            <div class="post-overlay" style="background: <?php echo $colors['title_bg']; ?>; color: <?php echo $colors['title_font']; ?>;">
                <h2 style="color: <?php echo $colors['title_font']; ?>;"><?php echo esc_html(get_the_title()); ?></h2>
            </div>
        </a>
        <?php
    }

    /**
     * Render sidebar post
     */
    private function render_sidebar_post($colors) {
        $image = has_post_thumbnail() ? get_the_post_thumbnail_url(get_the_ID(), 'medium') : 'https://via.placeholder.com/400x200';
        $categories = get_the_category();
        ?>
        <a href="<?php echo esc_url(get_permalink()); ?>" class="sidebar-post">
            <?php $this->render_categories($categories, $colors); ?>
            <div class="sidebar-image" style="background-image: url(<?php echo esc_url($image); ?>);">
                <div class="post-overlay" style="background: <?php echo $colors['title_bg']; ?>; color: <?php echo $colors['title_font']; ?>;">
                    <h3 style="color: <?php echo $colors['title_font']; ?>;"><?php echo esc_html(get_the_title()); ?></h3>
                </div>
            </div>
        </a>
        <?php
    }

    /**
     * Render categories
     */
    private function render_categories($categories, $colors) {
        if (!empty($categories)) {
            echo '<div class="category-container">';
            foreach ($categories as $category) {
                printf(
                    '<span class="category-badge" style="background: %s; color: %s;">%s</span>',
                    $colors['category_bg'],
                    $colors['category_font'],
                    esc_html($category->name)
                );
            }
            echo '</div>';
        }
    }
} 